unit ufBase64;
{$INCLUDE 'Filters.inc'}

interface

uses
  SysUtils, Classes,
  uXml,
  uFilter, uMessages;

type
  TFilterBase64 = class(TFilter)
  public
    class function ID: string; override;
    class function Name: string; override;
    class function Priority: TFilter.TPriority; override;
    class function AllowUncofigured: boolean; override;
    procedure Clear; override;
    function IsSupported(const FileName, Content: string): boolean; override;
    function Execute(const FileName, Content: string): string; override;
  end;

implementation

uses
  SynaCode;

{ TFilterBase64 }

class function TFilterBase64.AllowUncofigured: boolean;
begin
  Result := True;
end;

procedure TFilterBase64.Clear;
begin
  inherited;
  Description := GetMsg(MFilterBase64DecodeDescription);
  FileMasks.Add('*.b64');
end;

function TFilterBase64.Execute(const FileName, Content: string): string;
var
  Decoded: AnsiString;
begin
  Decoded := DecodeBase64( {$IFDEF UNICODE} AnsiString {$ENDIF} (Content));
  Result := {$IFDEF UNICODE} string {$ENDIF} (Decoded);
end;

class function TFilterBase64.ID: string;
begin
  Result := 'base64';
end;

function TFilterBase64.IsSupported(const FileName, Content: string): boolean;
var
  i, DataLen, EndingLen: integer;
begin
  Result := False;
  if inherited IsSupported(FileName, Content) then
  begin
    EndingLen := 0;
    DataLen := 0;
    for i := 1 to Length(Content) do
    begin
      case Ord(Content[i]) of
        13, 10, 9, 32:
          ;
        Ord('A')..Ord('Z'),
        Ord('a')..Ord('z'),
        Ord('0')..Ord('9'),
        Ord('+'),
        Ord('/'):
          if EndingLen > 0 then
            Exit
          else
            Inc(DataLen);
        Ord('='):
          Inc(EndingLen);
        else
          Exit;
      end;
    end;
    if EndingLen > 2 then
      Exit;
    DataLen := DataLen + EndingLen;
    if DataLen < 4 then
      Exit;
    if (DataLen mod 4) <> 0 then
      Exit;
    Result := True;
  end;
end;

class function TFilterBase64.Name: string;
begin
  Result := GetMsg(MFilterBase64DecodeName);
end;

class function TFilterBase64.Priority: TFilter.TPriority;
begin
  Result := prLow;
end;

initialization
  TRegisteredFilters.Add(TFilterBase64);

end.
